package MFImage;
use strict;
use warnings;

use rlib "./";

use MFValue;
use base qw(MFValue);

use SFImage;
our $SField = new SFImage;

1;
__END__
